@@ -21,6 +21,11 @@
 
 #include "color.h"
 
+enum temperature_unit {
+	CELCIUS,
+	FAHRENHEIT
+};
+
 enum sensorlist_position {
 	SENSORLIST_POSITION_RIGHT,
 	SENSORLIST_POSITION_LEFT,
@@ -37,7 +42,7 @@ struct config {
 	int alpha_channel_enabled;
 
 	/*
-	   Position of the sensors list table
+	 * Position of the sensors list table
 	 */
 	enum sensorlist_position sensorlist_position;
 
@@ -64,6 +69,8 @@ struct config {
 	int unity_launcher_count_disabled;
 
 	int hide_on_startup;
+
+	enum temperature_unit temperature_unit;
 };
 
 /*
@@ -71,25 +78,29 @@ struct config {
 */
 struct config *config_load();
 
-void config_save(struct config *);
-
-void config_init();
+void config_save(const struct config *);
 
 void config_cleanup();
 
-struct color *config_get_sensor_color(char *, struct color *);
-void config_set_sensor_color(char *, struct color *);
+struct color *config_get_sensor_color(const char *sid, const struct color *);
+void config_set_sensor_color(const char *sid, const struct color *);
 
-int config_get_sensor_alarm_limit(char *, int);
-void config_set_sensor_alarm_limit(char *, int);
+int config_get_sensor_alarm_high_threshold(const char *);
+void config_set_sensor_alarm_high_threshold(const char *, int);
 
-int config_get_sensor_alarm_enabled(char *);
-void config_set_sensor_alarm_enabled(char *, int);
+int config_get_sensor_alarm_low_threshold(const char *);
+void config_set_sensor_alarm_low_threshold(const char *, int);
 
-int config_is_sensor_enabled(char *);
-void config_set_sensor_enabled(char *, int);
+int config_get_sensor_alarm_enabled(const char *);
+void config_set_sensor_alarm_enabled(const char *, int);
 
-char *config_get_sensor_name(char *);
-void config_set_sensor_name(char *, const char *);
+int config_is_sensor_enabled(const char *);
+void config_set_sensor_enabled(const char *, int);
+
+char *config_get_sensor_name(const char *);
+void config_set_sensor_name(const char *, const char *);
+
+unsigned int config_is_appindicator_enabled(const char *);
+void config_set_appindicator_enabled(const char *, unsigned int);
 
 #endif
