@@ -76,27 +76,31 @@ draw_graph_background(cairo_t *cr,
 		      int g_xoff, int g_yoff,
 		      int g_width, int g_height,
 		      int width, int height, struct config *config,
-		      GtkWidget *widget)
+		      GtkWidget *widget,
+		      GtkWidget *window)
 {
-	GtkStyle *style;
-	struct color *bgcolor = config->graph_bgcolor;
-	GdkColor *bg;
+	GtkStyleContext *style_ctx;
+	struct color *bgcolor;
+	GdkRGBA rgba;
 
-	style = gtk_widget_get_style(widget);
+	bgcolor = config->graph_bgcolor;
 
-	bg = &style->bg[GTK_STATE_NORMAL];
+	style_ctx = gtk_widget_get_style_context(window);
+	gtk_style_context_get_background_color(style_ctx,
+					       GTK_STATE_FLAG_NORMAL,
+					       &rgba);
 
 	if (config->alpha_channel_enabled)
 		cairo_set_source_rgba(cr,
-				      ((double)bg->red) / 65535,
-				      ((double)bg->green) / 65535,
-				      ((double)bg->blue) / 65535,
+				      rgba.red,
+				      rgba.green,
+				      rgba.blue,
 				      config->graph_bg_alpha);
 	else
 		cairo_set_source_rgb(cr,
-				     ((double)bg->red) / 65535,
-				     ((double)bg->green) / 65535,
-				     ((double)bg->blue) / 65535);
+				     rgba.red,
+				     rgba.green,
+				     rgba.blue);
 
 	cairo_rectangle(cr, 0, 0, width, height);
 	cairo_fill(cr);
@@ -104,13 +108,13 @@ draw_graph_background(cairo_t *cr,
 		cairo_set_source_rgba(cr,
 				      bgcolor->f_red,
 				      bgcolor->f_green,
-				      bgcolor->f_blue, config->graph_bg_alpha);
+				      bgcolor->f_blue,
+				      config->graph_bg_alpha);
 	else
 		cairo_set_source_rgb(cr,
 				     bgcolor->f_red,
-				     bgcolor->f_green, bgcolor->f_blue);
-
-
+				     bgcolor->f_green,
+				     bgcolor->f_blue);
 
 	cairo_rectangle(cr, g_xoff, g_yoff, g_width, g_height);
 	cairo_fill(cr);
@@ -171,27 +175,28 @@ static void draw_sensor_curve(struct psensor *s,
 			      int g_xoff,
 			      int g_yoff)
 {
-	int first = 1;
-	int i;
+	int first, i, x, y, t, dt, vdt;
+	double v;
 
 	cairo_set_source_rgb(cr,
 			     s->color->f_red,
 			     s->color->f_green,
 			     s->color->f_blue);
-	cairo_set_line_join(cr, CAIRO_LINE_JOIN_ROUND);
-	cairo_set_line_width(cr, 1);
 
+	dt = et - bt;
+	first = 1;
 	for (i = 0; i < s->values_max_length; i++) {
-		int x, y, t;
-		double v;
-
 		t = s->measures[i].time.tv_sec;
-		v = s->measures[i].value.d_num;
+		v = s->measures[i].value;
 
-		if (v == UNKNOWN_DBL_VALUE || !t || (t - bt) < 0)
+		if (v == UNKNOWN_DBL_VALUE || !t)
 			continue;
 
-		x = (t - bt) * g_width / (et - bt) + g_xoff;
+		vdt = t - bt;
+		if (vdt < 0)
+			continue;
+
+		x = vdt * g_width / dt + g_xoff;
 
 		y = compute_y(v, min, max, g_height, g_yoff);
 
@@ -210,7 +215,8 @@ static void draw_sensor_curve(struct psensor *s,
 void
 graph_update(struct psensor **sensors,
 	     GtkWidget *w_graph,
-	     struct config *config)
+	     struct config *config,
+	     GtkWidget *window)
 {
 	struct color *fgcolor = config->graph_fgcolor;
 	int et, bt, width, height, g_width, g_height;
@@ -224,6 +230,8 @@ graph_update(struct psensor **sensors,
 	cairo_text_extents_t te_btime, te_etime, te_max, te_min;
 	struct psensor **sensor_cur;
 	GtkAllocation galloc;
+	GtkStyleContext *style_ctx;
+	GdkRGBA rgba;
 
 	if (!gtk_widget_is_drawable(w_graph))
 		return ;
@@ -232,10 +240,15 @@ graph_update(struct psensor **sensors,
 	max_rpm = get_max_rpm(sensors);
 
 	mint = get_min_temp(sensors);
-	strmin = psensor_value_to_string(SENSOR_TYPE_TEMP, mint);
+
+	strmin = psensor_value_to_str(SENSOR_TYPE_TEMP,
+				      mint,
+				      config->temperature_unit == CELCIUS);
 
 	maxt = get_max_temp(sensors);
-	strmax = psensor_value_to_string(SENSOR_TYPE_TEMP, maxt);
+	strmax = psensor_value_to_str(SENSOR_TYPE_TEMP,
+				      maxt,
+				      config->temperature_unit == CELCIUS);
 
 	str_btime = time_to_str(get_graph_begin_time_s(config));
 	str_etime = time_to_str(get_graph_end_time_s());
@@ -276,10 +289,13 @@ graph_update(struct psensor **sensors,
 	draw_graph_background(cr,
 			      g_xoff, g_yoff, g_width, g_height,
 			      width, height, config,
-			      w_graph);
+			      w_graph,
+			      window);
 
-	cairo_set_source_rgb(cr,
-			     fgcolor->f_red, fgcolor->f_green, fgcolor->f_blue);
+	/** Set the color for text drawing */
+	style_ctx = gtk_widget_get_style_context(window);
+	gtk_style_context_get_color(style_ctx, GTK_STATE_FLAG_NORMAL, &rgba);
+	cairo_set_source_rgb(cr, rgba.red, rgba.green, rgba.blue);
 
 	/* draw graph begin time */
 	cairo_move_to(cr, g_xoff, height - GRAPH_V_PADDING);
@@ -314,6 +330,9 @@ graph_update(struct psensor **sensors,
 
 	if (bt && et) {
 		sensor_cur = sensors;
+
+		cairo_set_line_join(cr, CAIRO_LINE_JOIN_ROUND);
+		cairo_set_line_width(cr, 1);
 		while (*sensor_cur) {
 			struct psensor *s = *sensor_cur;
 
