@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2011 thgreasi@gmail.com
+ * Copyright (C) 2010-2011 thgreasi@gmail.com, jeanfi@gmail.com
  * Copyright (C) 2010-2012 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
@@ -65,7 +65,7 @@ static void __stdcall *adl_main_memory_alloc(int isize)
 	return lpbuffer;
 }
 
-static void *getprocaddress(void *plibrary, const char * name)
+static void *getprocaddress(void *plibrary, const char *name)
 {
 	return dlsym(plibrary, name);
 }
@@ -147,8 +147,7 @@ static int init()
 	hdll = dlopen("libatiadlxx.so", RTLD_LAZY|RTLD_GLOBAL);
 
 	if (!hdll) {
-		fprintf(stderr,
-			_("ERROR: ADL library not found!\n"));
+		log_err(_("AMD: cannot found ADL library."));
 		return 0;
 	}
 
@@ -172,8 +171,7 @@ static int init()
 		!adl_adapter_adapterinfo_get ||
 		!adl_overdrive5_temperature_get ||
 		!adl_overdrive5_fanspeed_get) {
-		fprintf(stderr,
-			_("ERROR: ADL's API is missing!\n"));
+		log_err(_("AMD: missing ADL's API."));
 		return 0;
 	}
 
@@ -181,16 +179,14 @@ static int init()
 	   retrieve adapter information only for adapters that
 	   are physically present and enabled in the system */
 	if (ADL_OK != adl_main_control_create(adl_main_memory_alloc, 1)) {
-		fprintf(stderr,
-			_("ERROR: ADL Initialization Error!\n"));
+		log_err(_("AMD: failed to initialize ADL."));
 		return 0;
 	}
 	adl_main_control_done = 1;
 
 	/* Obtain the number of adapters for the system */
 	if (ADL_OK != adl_adapter_numberofadapters_get(&inumberadapters)) {
-		fprintf(stderr,
-			_("ERROR: Cannot get the number of adapters!\n"));
+		log_err(_("AMD: cannot get the number of adapters."));
 		return 0;
 	}
 
