@@ -19,11 +19,19 @@
 #ifndef _PSENSOR_HDD_H_
 #define _PSENSOR_HDD_H_
 
+#include "config.h"
 #include "psensor.h"
 
+#ifdef HAVE_ATASMART
 struct psensor **hdd_psensor_list_add(struct psensor **sensors,
 				      int values_max_length);
 
 void hdd_psensor_list_update(struct psensor **sensors);
+#endif
+
+struct psensor **hddtemp_psensor_list_add(struct psensor **sensors,
+				      int values_max_length);
+
+void hddtemp_psensor_list_update(struct psensor **sensors);
 
 #endif
