@@ -30,6 +30,8 @@ void log_open(const char *path);
 
 void log_printf(int lvl, const char *fmt, ...);
 void log_debug(const char *fmt, ...);
+void log_err(const char *fmt, ...);
+void log_warn(const char *fmt, ...);
 
 void log_close();
 
