@@ -30,7 +30,7 @@ struct measure *measures_dbl_create(int size)
 	result = malloc(size * sizeof(struct measure));
 
 	for (i = 0; i < size; i++) {
-		result[i].value.d_num = UNKNOWN_DBL_VALUE;
+		result[i].value = UNKNOWN_DBL_VALUE;
 		timerclear(&result[i].time);
 	}
 
