@@ -49,18 +49,20 @@ struct psensor *psensor_create(char *id, char *name,
 	psensor->values_max_length = values_max_length;
 	psensor->measures = measures_dbl_create(values_max_length);
 
-	psensor->alarm_limit = 0;
+	psensor->alarm_enabled = 0;
+	psensor->alarm_high_threshold = 0;
+	psensor->alarm_low_threshold = 0;
 
 	psensor->cb_alarm_raised = NULL;
 	psensor->cb_alarm_raised_data = NULL;
 	psensor->alarm_raised = 0;
 
-	psensor->alarm_enabled = 0;
-
 	psensor->url = NULL;
 
 	psensor->color = NULL;
 
+	psensor->appindicator_enabled = 0;
+
 	return psensor;
 }
 
@@ -89,6 +91,8 @@ void psensor_values_resize(struct psensor *s, int new_size)
 void psensor_free(struct psensor *sensor)
 {
 	if (sensor) {
+		log_debug("Cleanup %s", sensor->id);
+
 		free(sensor->name);
 		free(sensor->id);
 
@@ -198,26 +202,43 @@ int is_fan_type(unsigned int type)
 	return type & SENSOR_TYPE_FAN;
 }
 
-char *psensor_value_to_string(unsigned int type, double value)
+double celcius_to_fahrenheit(double c)
 {
-	/* should not be possible to exceed 20 characters with temp or
-	   rpm values the .x part is never displayed */
-	char *str = malloc(20);
+	return c * (9.0/5.0) + 32;
+}
 
-	char *unit;
+double fahrenheit_to_celcius(double f)
+{
+	return (f - 32) * (5.0/9.0);
+}
 
-	if (is_temp_type(type))
-		unit = "°C";
-	else if (type & SENSOR_TYPE_CPU_USAGE)
-		unit = "%";
-	else
-		unit = "";
+char *
+psensor_value_to_str(unsigned int type, double value, int use_celcius)
+{
+	char *str;
+	const char *unit;
+
+	/*
+	 * should not be possible to exceed 20 characters with temp or
+	 * rpm values the .x part is never displayed
+	 */
+	str = malloc(20);
+
+	unit = psensor_type_to_unit_str(type, use_celcius);
 
 	sprintf(str, "%.0f%s", value, unit);
 
 	return str;
 }
 
+char *
+psensor_measure_to_str(const struct measure *m,
+		       unsigned int type,
+		       unsigned int use_celcius)
+{
+	return psensor_value_to_str(type, m->value, use_celcius);
+}
+
 void psensor_set_current_value(struct psensor *sensor, double value)
 {
 	struct timeval tv;
@@ -236,7 +257,7 @@ psensor_set_current_measure(struct psensor *s,
 		&s->measures[1],
 		(s->values_max_length - 1) * sizeof(struct measure));
 
-	s->measures[s->values_max_length - 1].value.d_num = v;
+	s->measures[s->values_max_length - 1].value = v;
 	s->measures[s->values_max_length - 1].time = tv;
 
 	if (s->min == UNKNOWN_DBL_VALUE || v < s->min)
@@ -245,11 +266,10 @@ psensor_set_current_measure(struct psensor *s,
 	if (s->max == UNKNOWN_DBL_VALUE || v > s->max)
 		s->max = v;
 
-	if (s->alarm_limit && s->alarm_enabled) {
-		if (v > s->alarm_limit) {
+	if (s->alarm_enabled) {
+		if (v > s->alarm_high_threshold || v < s->alarm_low_threshold) {
 			if (!s->alarm_raised && s->cb_alarm_raised)
-				s->cb_alarm_raised(s,
-						   s->cb_alarm_raised_data);
+				s->cb_alarm_raised(s, s->cb_alarm_raised_data);
 
 			s->alarm_raised = 1;
 		} else {
@@ -260,7 +280,7 @@ psensor_set_current_measure(struct psensor *s,
 
 double psensor_get_current_value(struct psensor *sensor)
 {
-	return sensor->measures[sensor->values_max_length - 1].value.d_num;
+	return sensor->measures[sensor->values_max_length - 1].value;
 }
 
 struct measure *psensor_get_current_measure(struct psensor *sensor)
@@ -285,7 +305,7 @@ double get_min_value(struct psensor **sensors, int type)
 			double t;
 
 			for (i = 0; i < sensor->values_max_length; i++) {
-				t = sensor->measures[i].value.d_num;
+				t = sensor->measures[i].value;
 
 				if (t == UNKNOWN_DBL_VALUE)
 					continue;
@@ -316,7 +336,7 @@ double get_max_value(struct psensor **sensors, int type)
 			int i;
 			double t;
 			for (i = 0; i < sensor->values_max_length; i++) {
-				t = sensor->measures[i].value.d_num;
+				t = sensor->measures[i].value;
 
 				if (t == UNKNOWN_DBL_VALUE)
 					continue;
@@ -373,18 +393,31 @@ double get_max_temp(struct psensor **sensors)
 	return get_max_value(sensors, SENSOR_TYPE_TEMP);
 }
 
-struct psensor **get_all_sensors(int values_max_length)
+struct psensor **get_all_sensors(int use_libatasmart, int values_max_length)
 {
 	struct psensor **psensors = NULL;
 	struct psensor **tmp_psensors;
 
 	psensors = lmsensor_psensor_list_add(NULL, values_max_length);
 
-	tmp_psensors = hdd_psensor_list_add(psensors, values_max_length);
-	if (tmp_psensors != psensors) {
-		free(psensors);
-		psensors = tmp_psensors;
+	if (!use_libatasmart) {
+		tmp_psensors = hddtemp_psensor_list_add(psensors,
+							values_max_length);
+		if (tmp_psensors != psensors) {
+			free(psensors);
+			psensors = tmp_psensors;
+		}
 	}
+#ifdef HAVE_ATASMART
+		else {
+			tmp_psensors = hdd_psensor_list_add(psensors,
+							    values_max_length);
+			if (tmp_psensors != psensors) {
+				free(psensors);
+				psensors = tmp_psensors;
+			}
+		}
+#endif
 
 	if (!psensors) {	/* there is no detected sensors */
 		psensors = malloc(sizeof(struct psensor *));
@@ -424,18 +457,20 @@ const char *psensor_type_to_str(unsigned int type)
 }
 
 
-const char *psensor_type_to_unit_str(unsigned int type)
+const char *psensor_type_to_unit_str(unsigned int type, int use_celcius)
 {
-	if (type & SENSOR_TYPE_TEMP)
-		return "\302\260C";
-
-	if (type & SENSOR_TYPE_FAN)
+	if (is_temp_type(type)) {
+		if (use_celcius)
+			return "\302\260C";
+		else
+			return "\302\260F";
+	} else if (is_fan_type(type)) {
 		return _("RPM");
-
-	if (type & SENSOR_TYPE_CPU_USAGE)
+	} else if (type & SENSOR_TYPE_CPU_USAGE) {
 		return _("%");
-
-	return "N/A";
+	} else {
+		return _("N/A");
+	}
 }
 
 void psensor_list_update_measures(struct psensor **sensors)
@@ -446,8 +481,26 @@ void psensor_list_update_measures(struct psensor **sensors)
 	cpu_psensor_list_update(sensors);
 #endif
 
-	if (psensor_list_contains_type(sensors, SENSOR_TYPE_HDD_TEMP))
+	if (psensor_list_contains_type(sensors, SENSOR_TYPE_HDD_TEMP_HDDTEMP))
+		hddtemp_psensor_list_update(sensors);
+
+#ifdef HAVE_ATASMART
+	if (psensor_list_contains_type(sensors,
+				       SENSOR_TYPE_HDD_TEMP_ATASMART))
 		hdd_psensor_list_update(sensors);
+#endif
+}
+
+void psensor_log_measures(struct psensor **sensors)
+{
+	if (log_level == LOG_DEBUG)
+		while (*sensors) {
+			log_debug("Measure: %s %.2f",
+				   (*sensors)->name,
+				   psensor_get_current_value(*sensors));
+
+			sensors++;
+		}
 }
 
 void psensor_init()
