@@ -22,6 +22,10 @@
 #include "config.h"
 #include <sensors/sensors.h>
 
+#ifdef HAVE_ATASMART
+#include <atasmart.h>
+#endif
+
 #include "color.h"
 #include "log.h"
 #include "measure.h"
@@ -37,6 +41,9 @@ enum psensor_type {
 	SENSOR_TYPE_CPU_USAGE = 0x0800,
 	SENSOR_TYPE_AMD = 0x1000,
 
+	SENSOR_TYPE_HDD_TEMP_ATASMART = 0x2000 | SENSOR_TYPE_HDD_TEMP,
+	SENSOR_TYPE_HDD_TEMP_HDDTEMP = 0x4000 | SENSOR_TYPE_HDD_TEMP,
+
 	SENSOR_TYPE_AMD_TEMP = SENSOR_TYPE_AMD | SENSOR_TYPE_TEMP,
 	SENSOR_TYPE_AMD_FAN = SENSOR_TYPE_AMD | SENSOR_TYPE_FAN,
 
@@ -65,8 +72,8 @@ struct psensor {
 	/* Color of the sensor used for the graph */
 	struct color *color;
 
-	/* Whether the sensor is displayed in the graph */
-	int enabled;
+	/* Whether the graph sensor is displayed. */
+	unsigned int enabled;
 
 	/* see psensor_type */
 	unsigned int type;
@@ -77,19 +84,14 @@ struct psensor {
 	/* The minimum detected value of the sensor */
 	double min;
 
-	/*
-	   Whether alarm alerts is enabled for this sensor
-	 */
-	int alarm_enabled;
+	/* Whether alarm alert is enabled for this sensor */
+	unsigned int alarm_enabled;
 
-	/*
-	   An alarm is raised if the current sensor value is bigger. 0
-	   means no limit
-	 */
-	double alarm_limit;
+	int alarm_high_threshold;
+	int alarm_low_threshold;
 
-	/* Whether the current value is bigger than 'alarm_limit'.  */
-	int alarm_raised;
+	/* Whether an alarm is raised for this sensor */
+	unsigned int alarm_raised;
 
 	void (*cb_alarm_raised) (struct psensor *, void *);
 	void *cb_alarm_raised_data;
@@ -102,8 +104,13 @@ struct psensor {
 	/* AMD id for the aticonfig */
 	int amd_id;
 #endif
+#ifdef HAVE_ATASMART
+	SkDisk *disk;
+#endif
 
 	char *url;
+
+	unsigned int appindicator_enabled;
 };
 
 struct psensor *psensor_create(char *id,
@@ -146,9 +153,15 @@ psensor_get_max_current_value(struct psensor **sensors, unsigned int type);
   parameter 'type' is SENSOR_TYPE_LMSENSOR_TEMP, SENSOR_TYPE_NVIDIA,
   or SENSOR_TYPE_LMSENSOR_FAN
 */
-char *psensor_value_to_string(unsigned int type, double value);
+char *psensor_value_to_str(unsigned int type,
+			   double value,
+			   int use_celcius);
 
-struct psensor **get_all_sensors(int values_max_length);
+char *psensor_measure_to_str(const struct measure *m,
+			     unsigned int type,
+			     unsigned int use_celcius);
+
+struct psensor **get_all_sensors(int use_libatasmart, int values_max_length);
 
 struct psensor **psensor_list_add(struct psensor **sensors,
 				  struct psensor *sensor);
@@ -166,7 +179,7 @@ struct measure *psensor_get_current_measure(struct psensor *sensor);
 */
 const char *psensor_type_to_str(unsigned int type);
 
-const char *psensor_type_to_unit_str(unsigned int type);
+const char *psensor_type_to_unit_str(unsigned int type, int use_celcius);
 
 void psensor_list_update_measures(struct psensor **sensors);
 
@@ -176,4 +189,10 @@ void psensor_cleanup();
 
 double get_max_value(struct psensor **sensors, int type);
 
+double celcius_to_fahrenheit(double c);
+double fahrenheit_to_celcius(double c);
+
+
+void psensor_log_measures(struct psensor **sensors);
+
 #endif
