@@ -87,7 +87,7 @@ static void print_help()
 {
 	printf(_("Usage: %s [OPTION]...\n"), program_name);
 
-	puts(_("psensor is a GTK application for monitoring hardware sensors, "
+	puts(_("Psensor is a GTK+ application for monitoring hardware sensors, "
 	       "including temperatures and fan speeds."));
 
 	puts("");
@@ -97,9 +97,14 @@ static void print_help()
 
 	puts("");
 
-	puts(_("  -u, --url=URL       "
-	       "the URL of the psensor-server, example: http://hostname:3131"));
-
+	puts(_(
+"  -u, --url=URL       the URL of the psensor-server,\n"
+"                      example: http://hostname:3131"));
+	puts(_(
+"  --use-libatasmart   use atasmart library for disk monitoring instead of\n"
+"                      hddtemp daemon"));
+	puts(_(
+"  -n, --new-instance  force the creation of a new Psensor application"));
 	puts("");
 
 	puts(_("  -d, --debug=LEVEL   "
@@ -113,50 +118,39 @@ static void print_help()
 }
 
 /*
-  Updates the size of the sensor values if different than the
-  configuration.
+ * Updates the size of the sensor values if different than the
+ * configuration.
  */
-void
+static void
 update_psensor_values_size(struct psensor **sensors, struct config *cfg)
 {
-	struct psensor **cur;
+	struct psensor **cur, *s;
 
-	cur = sensors;
-	while (*cur) {
-		struct psensor *s = *cur;
+	for (cur = sensors; *cur; cur++) {
+		s = *cur;
 
 		if (s->values_max_length != cfg->sensor_values_max_length)
 			psensor_values_resize(s,
 					      cfg->sensor_values_max_length);
-
-		cur++;
 	}
 }
 
-static void log_measures(struct psensor **sensors)
+static void update_measures(struct ui_psensor *ui)
 {
-	if (log_level == LOG_DEBUG)
-		while (*sensors) {
-			log_debug("Measure: %s %.2f",
-				   (*sensors)->name,
-				   psensor_get_current_value(*sensors));
+	struct psensor **sensors;
+	struct config *cfg;
+	int period;
 
-			sensors++;
-		}
-}
-
-void update_psensor_measures(struct ui_psensor *ui)
-{
-	struct psensor **sensors = ui->sensors;
-	struct config *cfg = ui->config;
+	cfg = ui->config;
 
 	while (1) {
 		g_mutex_lock(ui->sensors_mutex);
 
+		sensors = ui->sensors;
 		if (!sensors)
 			return;
 
-		update_psensor_values_size(sensors, ui->config);
+		update_psensor_values_size(sensors, cfg);
 
 		psensor_list_update_measures(sensors);
 #ifdef HAVE_REMOTE_SUPPORT
@@ -169,11 +163,13 @@ void update_psensor_measures(struct ui_psensor *ui)
 		amd_psensor_list_update(sensors);
 #endif
 
-		log_measures(sensors);
+		psensor_log_measures(sensors);
+
+		period = cfg->sensor_update_interval;
 
 		g_mutex_unlock(ui->sensors_mutex);
 
-		sleep(cfg->sensor_update_interval);
+		sleep(period);
 	}
 }
 
@@ -213,7 +209,7 @@ gboolean ui_refresh_thread(gpointer data)
 
 	g_mutex_lock(ui->sensors_mutex);
 
-	graph_update(ui->sensors, ui->w_graph, ui->config);
+	graph_update(ui->sensors, ui->w_graph, ui->config, ui->main_window);
 
 	ui_sensorlist_update(ui);
 
@@ -222,7 +218,8 @@ gboolean ui_refresh_thread(gpointer data)
 
 #ifdef HAVE_UNITY
 	ui_unity_launcher_entry_update(ui->sensors,
-				       !cfg->unity_launcher_count_disabled);
+				       !cfg->unity_launcher_count_disabled,
+				       cfg->temperature_unit == CELCIUS);
 #endif
 
 	if (ui->graph_update_interval != cfg->graph_update_interval) {
@@ -239,10 +236,10 @@ gboolean ui_refresh_thread(gpointer data)
 	return ret;
 }
 
-void cb_alarm_raised(struct psensor *sensor, void *data)
+static void cb_alarm_raised(struct psensor *sensor, void *data)
 {
 #ifdef HAVE_LIBNOTIFY
-	if (sensor->enabled)
+	if (sensor->alarm_enabled)
 		ui_notify(sensor, (struct ui_psensor *)data);
 #endif
 }
@@ -255,7 +252,7 @@ static void associate_colors(struct psensor **sensors)
 	unsigned int colors[COLORS_COUNT][3] = {
 		{0x0000, 0x0000, 0x0000},	/* black */
 		{0xffff, 0x0000, 0x0000},	/* red */
-		{0x0000, 0.0000, 0xffff},	/* blue */
+		{0x0000, 0x0000, 0xffff},	/* blue */
 		{0x0000, 0xffff, 0x0000},	/* green */
 
 		{0x7fff, 0x7fff, 0x7fff},	/* grey */
@@ -292,13 +289,16 @@ associate_cb_alarm_raised(struct psensor **sensors, struct ui_psensor *ui)
 		s->cb_alarm_raised = cb_alarm_raised;
 		s->cb_alarm_raised_data = ui;
 
-		if (is_temp_type(s->type)) {
-			s->alarm_limit
-			    = config_get_sensor_alarm_limit(s->id, 60);
+		s->alarm_high_threshold
+			= config_get_sensor_alarm_high_threshold(s->id);
+		s->alarm_low_threshold
+			= config_get_sensor_alarm_low_threshold(s->id);
+
+		if (is_temp_type(s->type) || is_fan_type(s->type)) {
 			s->alarm_enabled
 			    = config_get_sensor_alarm_enabled(s->id);
 		} else {
-			s->alarm_limit = 0;
+			s->alarm_high_threshold = 0;
 			s->alarm_enabled = 0;
 		}
 
@@ -317,8 +317,12 @@ static void associate_preferences(struct psensor **sensors)
 
 		n = config_get_sensor_name(s->id);
 
-		if (n)
+		if (n) {
+			free(s->name);
 			s->name = n;
+		}
+
+		s->appindicator_enabled = config_is_appindicator_enabled(s->id);
 
 		sensor_cur++;
 	}
@@ -347,10 +351,12 @@ static void log_init()
 }
 
 static struct option long_options[] = {
+	{"use-libatasmart", no_argument, 0, 0},
 	{"version", no_argument, 0, 'v'},
 	{"help", no_argument, 0, 'h'},
 	{"url", required_argument, 0, 'u'},
 	{"debug", required_argument, 0, 'd'},
+	{"new-instance", no_argument, 0, 'n'},
 	{0, 0, 0, 0}
 };
 
@@ -389,13 +395,96 @@ static void log_glib_info()
 		  glib_micro_version);
 }
 
+static void cb_activate(GApplication *application,
+			gpointer data)
+{
+	ui_window_show((struct ui_psensor *)data);
+}
+
+/*
+ * Release memory for Valgrind.
+ */
+static void cleanup(struct ui_psensor *ui)
+{
+	g_mutex_lock(ui->sensors_mutex);
+
+	log_debug("Cleanup...");
+
+	psensor_cleanup();
+
+#ifdef HAVE_NVIDIA
+	nvidia_cleanup();
+#endif
+#ifdef HAVE_LIBATIADL
+	amd_cleanup();
+#endif
+#ifdef HAVE_REMOTE_SUPPORT
+	rsensor_cleanup();
+#endif
+
+	psensor_list_free(ui->sensors);
+	ui->sensors = NULL;
+
+#if defined(HAVE_APPINDICATOR) || defined(HAVE_APPINDICATOR_029)
+	ui_appindicator_cleanup();
+#endif
+
+	ui_status_cleanup();
+
+	g_mutex_unlock(ui->sensors_mutex);
+
+	config_cleanup();
+
+	log_debug("Cleanup done, closing log");
+}
+
+/*
+ * Creates the list of sensors.
+ *
+ * 'url': remote psensor server url, null for local monitoring.
+ * 'use_libatasmart': whether the libatasmart must be used.
+ */
+static struct psensor **create_sensors_list(const char *url,
+					    unsigned int use_libatasmart)
+{
+	struct psensor **sensors;
+
+	if (url) {
+#ifdef HAVE_REMOTE_SUPPORT
+		rsensor_init();
+		sensors = get_remote_sensors(url, 600);
+#else
+		log_err(_("Psensor has not been compiled with remote "
+			  "sensor support."));
+		exit(EXIT_FAILURE);
+#endif
+	} else {
+		sensors = get_all_sensors(use_libatasmart, 600);
+#ifdef HAVE_NVIDIA
+		sensors = nvidia_psensor_list_add(sensors, 600);
+#endif
+#ifdef HAVE_LIBATIADL
+		sensors = amd_psensor_list_add(sensors, 600);
+#endif
+#ifdef HAVE_GTOP
+		sensors = cpu_psensor_list_add(sensors, 600);
+#endif
+	}
+
+	associate_preferences(sensors);
+	associate_colors(sensors);
+
+	return sensors;
+}
+
 int main(int argc, char **argv)
 {
 	struct ui_psensor ui;
 	GError *error;
 	GThread *thread;
-	int optc, cmdok;
+	int optc, cmdok, opti, use_libatasmart, new_instance;
 	char *url = NULL;
+	GApplication *app;
 
 	program_name = argv[0];
 
@@ -406,10 +495,16 @@ int main(int argc, char **argv)
 	textdomain(PACKAGE);
 #endif
 
+	use_libatasmart = new_instance = 0;
+
 	cmdok = 1;
-	while ((optc = getopt_long(argc, argv, "vhd:u:", long_options,
-				   NULL)) != -1) {
+	while ((optc = getopt_long(argc, argv, "vhd:u:n", long_options,
+				   &opti)) != -1) {
 		switch (optc) {
+		case 0:
+			if (!strcmp(long_options[opti].name, "use-libatasmart"))
+				use_libatasmart = 1;
+			break;
 		case 'u':
 			if (optarg)
 				url = strdup(optarg);
@@ -424,6 +519,9 @@ int main(int argc, char **argv)
 			log_level = atoi(optarg);
 			log_printf(LOG_INFO, _("Enables debug mode."));
 			break;
+		case 'n':
+			new_instance = 1;
+			break;
 		default:
 			cmdok = 0;
 			break;
@@ -438,6 +536,18 @@ int main(int argc, char **argv)
 
 	log_init();
 
+	app = g_application_new("wpitchoune.psensor", 0);
+
+	g_application_register(app, NULL, NULL);
+
+	if (!new_instance && g_application_get_is_remote(app)) {
+		g_application_activate(app);
+		log_warn(_("A Psensor instance already exists."));
+		exit(EXIT_SUCCESS);
+	}
+
+	g_signal_connect(app, "activate", G_CALLBACK(cb_activate), &ui);
+
 	log_glib_info();
 #if !(GLIB_CHECK_VERSION(2, 31, 0))
 	/*
@@ -454,40 +564,16 @@ int main(int argc, char **argv)
 
 	ui.sensors_mutex = g_mutex_new();
 
-	config_init();
-
 	ui.config = config_load();
 
 	psensor_init();
 
-	if (url) {
-#ifdef HAVE_REMOTE_SUPPORT
-		rsensor_init();
-		ui.sensors = get_remote_sensors(url, 600);
-#else
-		fprintf(stderr,
-			_("ERROR: Not compiled with remote sensor support.\n"));
-		exit(EXIT_FAILURE);
-#endif
-	} else {
-		ui.sensors = get_all_sensors(600);
-#ifdef HAVE_NVIDIA
-		ui.sensors = nvidia_psensor_list_add(ui.sensors, 600);
-#endif
-#ifdef HAVE_LIBATIADL
-		ui.sensors = amd_psensor_list_add(ui.sensors, 600);
-#endif
-#ifdef HAVE_GTOP
-		ui.sensors = cpu_psensor_list_add(ui.sensors, 600);
-#endif
-	}
-
-	associate_preferences(ui.sensors);
-	associate_colors(ui.sensors);
+	ui.sensors = create_sensors_list(url, use_libatasmart);
 	associate_cb_alarm_raised(ui.sensors, &ui);
 
 #if !defined(HAVE_APPINDICATOR) && !defined(HAVE_APPINDICATOR_029)
 	ui_status_init(&ui);
+	ui_status_set_visible(1);
 #endif
 
 	/* main window */
@@ -497,10 +583,12 @@ int main(int argc, char **argv)
 	/* drawing box */
 	ui.w_graph = ui_graph_create(&ui);
 
+	ui_enable_alpha_channel(&ui);
+
 	/* sensor list */
 	ui_sensorlist_create(&ui);
 
-	thread = g_thread_create((GThreadFunc) update_psensor_measures,
+	thread = g_thread_create((GThreadFunc) update_measures,
 				 &ui, TRUE, &error);
 
 	if (!thread)
@@ -527,33 +615,10 @@ int main(int argc, char **argv)
 	/* main loop */
 	gtk_main();
 
-	g_mutex_lock(ui.sensors_mutex);
-
-	psensor_cleanup();
-
-#ifdef HAVE_NVIDIA
-	nvidia_cleanup();
-#endif
-#ifdef HAVE_LIBATIADL
-	amd_cleanup();
-#endif
-#ifdef HAVE_REMOTE_SUPPORT
-	rsensor_cleanup();
-#endif
-
-	psensor_list_free(ui.sensors);
-	ui.sensors = NULL;
-
-#if defined(HAVE_APPINDICATOR) || defined(HAVE_APPINDICATOR_029)
-	ui_appindicator_cleanup();
-#endif
-
-	ui_status_cleanup();
-
-	g_mutex_unlock(ui.sensors_mutex);
-
-	config_cleanup();
+	g_object_ref(app);
+	cleanup(&ui);
 
+	log_debug("Quitting...");
 	log_close();
 
 	return 0;
