@@ -65,7 +65,7 @@ static GtkActionEntry entries[] = {
 	  G_CALLBACK(cb_preferences) },
 
 	{ "SensorPreferencesAction", GTK_STOCK_PREFERENCES,
-	  "_Sensor Preferences", NULL,
+	  "S_ensor Preferences", NULL,
 	  "Sensor Preferences",
 	  G_CALLBACK(cb_sensor_preferences) },
 
@@ -124,12 +124,14 @@ on_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer data)
 	struct ui_psensor *ui_psensor = (struct ui_psensor *)data;
 
 	graph_update(ui_psensor->sensors,
-		     ui_psensor->w_graph, ui_psensor->config);
+		     ui_psensor->w_graph,
+		     ui_psensor->config,
+		     ui_psensor->main_window);
 
 	return FALSE;
 }
 
-GtkWidget *ui_graph_create(struct ui_psensor * ui)
+GtkWidget *ui_graph_create(struct ui_psensor *ui)
 {
 	GtkWidget *w_graph;
 
