@@ -46,13 +46,14 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 	GError *error = NULL;
 	GdkColor *color_fg, *color_bg;
 	GtkColorButton *w_color_fg, *w_color_bg;
-	GtkHScale *w_bg_opacity;
+	GtkScale *w_bg_opacity;
 	GtkSpinButton *w_update_interval, *w_monitoring_duration,
 		*w_s_update_interval;
 	GtkComboBox *w_sensorlist_pos;
 	GtkToggleButton *w_hide_window_decoration, *w_keep_window_below,
 		*w_enable_menu, *w_enable_launcher_counter, *w_hide_on_startup,
 		*w_win_restore;
+	GtkComboBoxText *w_temp_unit;
 
 	cfg = ui->config;
 
@@ -81,8 +82,8 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 							     "color_bg"));
 	gtk_color_button_set_color(w_color_bg, color_bg);
 
-	w_bg_opacity = GTK_HSCALE(gtk_builder_get_object(builder,
-							 "bg_opacity"));
+	w_bg_opacity = GTK_SCALE(gtk_builder_get_object(builder,
+							"bg_opacity"));
 	gtk_range_set_value(GTK_RANGE(w_bg_opacity), cfg->graph_bg_alpha);
 
 	w_update_interval = GTK_SPIN_BUTTON(gtk_builder_get_object
@@ -136,6 +137,12 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 	gtk_toggle_button_set_active(w_win_restore,
 				     cfg->window_restore_enabled);
 
+	w_temp_unit
+		= GTK_COMBO_BOX_TEXT(gtk_builder_get_object
+				     (builder, "temperature_unit"));
+	gtk_combo_box_set_active(GTK_COMBO_BOX(w_temp_unit),
+				 cfg->temperature_unit);
+
 	result = gtk_dialog_run(diag);
 
 	if (result == GTK_RESPONSE_ACCEPT) {
@@ -202,6 +209,9 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 		cfg->window_restore_enabled
 			= gtk_toggle_button_get_active(w_win_restore);
 
+		cfg->temperature_unit
+			= gtk_combo_box_get_active(GTK_COMBO_BOX(w_temp_unit));
+
 		config_save(cfg);
 
 		g_mutex_unlock(ui->sensors_mutex);
